@@ -138,7 +138,7 @@ def early_kn_candidates(
     if f_kn.any():
         # load mangrove catalog
         curdir = os.path.dirname(os.path.abspath(__file__))
-        mangrove_path = curdir + '/data/mangrove_filtered.csv'
+        mangrove_path = curdir + '/../data/mangrove_filtered.csv'
         pdf_mangrove = pd.read_csv(mangrove_path)
 
         catalog_mangrove = SkyCoord(
